<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/About.qml" line="27"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="46"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="49"/>
        <source>Thanks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="52"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="86"/>
        <source>Version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="90"/>
        <source>Using Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="94"/>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="103"/>
        <source>Webcam capture application.</source>
        <translation type="unfinished">Aplikacja do przechwytywania kamer internetowych.</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="106"/>
        <source>A simple webcam application for picture and video capture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="122"/>
        <source>Thanks to all these cool people that helped contributing to Webcamoid all these years.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="149"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddMedia</name>
    <message>
        <location filename="../qml/AddMedia.qml" line="28"/>
        <source>Add new media</source>
        <translation>Dodaj nowe media</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="67"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="74"/>
        <source>Insert media description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="81"/>
        <source>Media file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="89"/>
        <source>Select media file</source>
        <translation>Wybierz plik multimedialny</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="96"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="116"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="141"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="151"/>
        <source>Choose the file to add as media</source>
        <translation>Wybierz plik, który chcesz dodać jako nośnik</translation>
    </message>
</context>
<context>
    <name>AudioConfig</name>
    <message>
        <location filename="../qml/AudioConfig.qml" line="117"/>
        <source>Outputs</source>
        <translation>Wyjć</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="121"/>
        <source>Select the output device for audio playing</source>
        <translation>Wybierz urządzenie wyjściowe do odtwarzania dźwięku</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="134"/>
        <source>Inputs</source>
        <translation>Wejścia</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="137"/>
        <source>Select the device for audio capturing</source>
        <translation>Wybierz urządzenie do przechwytywania dźwięku</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="193"/>
        <location filename="../qml/AudioConfig.qml" line="295"/>
        <source>Silence</source>
        <translation>Wycisz</translation>
    </message>
</context>
<context>
    <name>AudioInfo</name>
    <message>
        <location filename="../qml/AudioInfo.qml" line="199"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="214"/>
        <location filename="../qml/AudioInfo.qml" line="221"/>
        <source>Device description</source>
        <translation>Opis urządzenia</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="229"/>
        <location filename="../qml/AudioInfo.qml" line="244"/>
        <location filename="../qml/AudioInfo.qml" line="251"/>
        <source>Device id</source>
        <translation>Identyfikator urzadzenia</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="266"/>
        <source>Sample Format</source>
        <translation>Przykładowy format</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="292"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="318"/>
        <source>Sample Rate</source>
        <translation>Częstotliwość próbkowania</translation>
    </message>
</context>
<context>
    <name>CodecConfigs</name>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="27"/>
        <source>Configure %1</source>
        <translation>Skonfiguruj %1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="112"/>
        <source>Search option</source>
        <translation>Opcja wyszukiwania</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="126"/>
        <source>Reset</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="141"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="151"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfigBar</name>
    <message>
        <location filename="../qml/ConfigBar.qml" line="44"/>
        <source>Output</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="48"/>
        <source>General Options</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="52"/>
        <source>Plugins Configs</source>
        <translation>Wtyczki Configs</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="56"/>
        <source>Updates</source>
        <translation>Aktualizacje</translation>
    </message>
</context>
<context>
    <name>EffectBar</name>
    <message>
        <location filename="../qml/EffectBar.qml" line="122"/>
        <source>Search effect...</source>
        <translation>Efekt wyszukiwania ...</translation>
    </message>
    <message>
        <location filename="../qml/EffectBar.qml" line="168"/>
        <source>None</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EffectConfig</name>
    <message>
        <location filename="../qml/EffectConfig.qml" line="96"/>
        <location filename="../qml/EffectConfig.qml" line="103"/>
        <source>Plugin id</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="83"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="90"/>
        <source>Plugin description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="119"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="119"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>GeneralConfig</name>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="46"/>
        <source>Play webcam on start</source>
        <translation>Uruchom kamerę internetową przy starcie</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="52"/>
        <source>Enable advanced effects mode</source>
        <translation>Włącz zaawansowany tryb efektów</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="58"/>
        <source>Frameworks &amp; libraries</source>
        <translation>Struktura i biblioteki</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="68"/>
        <source>Video capture</source>
        <translation>Przechwytywanie wideo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="78"/>
        <source>Desktop capture</source>
        <translation>Przechwytywanie pulpitu</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="88"/>
        <source>Audio capture/play</source>
        <translation>Przechwytywanie/odtwarzanie dźwięku</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="98"/>
        <source>Video convert</source>
        <translation>Konwersja wideo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="108"/>
        <source>Audio convert</source>
        <translation>Konwersja audio</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="149"/>
        <source>Virtual camera driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="118"/>
        <source>Video playback</source>
        <translation>Odtwarzanie wideo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="128"/>
        <source>Video record</source>
        <translation>Nagrywanie wideo</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="138"/>
        <source>Root method</source>
        <translation>Metoda korzeniowa</translation>
    </message>
</context>
<context>
    <name>MediaBar</name>
    <message>
        <location filename="../qml/MediaBar.qml" line="62"/>
        <source>No webcams found</source>
        <translation>Nie znaleziono kamer internetowych</translation>
    </message>
</context>
<context>
    <name>MediaConfig</name>
    <message>
        <location filename="../qml/MediaConfig.qml" line="54"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="61"/>
        <source>Insert media description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="68"/>
        <source>Media UID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="75"/>
        <source>Select media file</source>
        <translation>Wybierz plik multimedialny</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="90"/>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="98"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>MediaTools</name>
    <message>
        <location filename="../../src/mediatools.cpp" line="223"/>
        <source>Daily Build</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputConfig</name>
    <message>
        <location filename="../qml/OutputConfig.qml" line="55"/>
        <source>Virtual camera</source>
        <translation>Wirtualna kamera</translation>
    </message>
</context>
<context>
    <name>PhotoWidget</name>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="35"/>
        <source>%1 seconds</source>
        <translation>%1 sekund</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="56"/>
        <source>Now</source>
        <translation>Teraz</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="80"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="80"/>
        <source>Shot!</source>
        <translation>Strzał!</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="111"/>
        <source>Use flash</source>
        <translation>Skorzystaj z lampy błyskowej</translation>
    </message>
</context>
<context>
    <name>PluginConfig</name>
    <message>
        <location filename="../qml/PluginConfig.qml" line="110"/>
        <source>Use this page for configuring the plugins search paths.&lt;br /&gt;&lt;b&gt;Don&apos;t touch nothing unless you know what you are doing&lt;/b&gt;.</source>
        <translation>Ta strona służy do konfigurowania ścieżek wyszukiwania wtyczek.&lt;br /&gt;&lt;b&gt;Nie dotykaj niczego, jeśli nie wiesz, co robisz&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="115"/>
        <source>Extra search paths</source>
        <translation>Dodatkowe ścieżki wyszukiwania</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="124"/>
        <source>Search plugins in subfolders.</source>
        <translation>Wyszukaj wtyczki w podfolderach.</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="134"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="141"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="207"/>
        <source>Plugins list</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="216"/>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="226"/>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="226"/>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="308"/>
        <source>Add plugins search path</source>
        <translation>Dodaj ścieżkę wyszukiwania wtyczek</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/clioptions.cpp" line="45"/>
        <source>Webcam capture application.</source>
        <translation>Aplikacja do przechwytywania kamer internetowych.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="48"/>
        <source>Load settings from PATH. If PATH is empty, load configs from application directory.</source>
        <translation>Załaduj ustawienia z PATH. Jeśli PATH jest pusta, załaduj configs z katalogu aplikacji.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="50"/>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="54"/>
        <source>Semi-colon separated list of paths to search the Qml interface.</source>
        <translation>Lista rozdzielona średnikami, zawierająca ścieżki do przeszukiwania interfejsu Qml.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="56"/>
        <location filename="../../src/clioptions.cpp" line="68"/>
        <location filename="../../src/clioptions.cpp" line="74"/>
        <location filename="../../src/clioptions.cpp" line="80"/>
        <source>PATH1;PATH2;PATH3;...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="61"/>
        <source>Search in the specified plugins paths recursively.</source>
        <translation>Szukaj w określonych ścieżkach wtyczek rekurencyjnie.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="66"/>
        <source>Semi-colon separated list of paths to search for plugins.</source>
        <translation>Lista rozdzielona średnikami, zawierająca ścieżki do wyszukiwania wtyczek.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="72"/>
        <source>Semi-colon separated list of paths to avoid loading.</source>
        <translation>Lista ścieżek rozdzielona średnikami, aby uniknąć ładowania.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="78"/>
        <source>Semi-colon separated list of paths to search for virtual camera driver</source>
        <translation>Lista rozdzielonych średnikami wykazów ścieżek wyszukiwania wirtualnego sterownika kamery</translation>
    </message>
</context>
<context>
    <name>RecordBar</name>
    <message>
        <location filename="../qml/RecordBar.qml" line="101"/>
        <source>Search format...</source>
        <translation>Wyszukaj format ...</translation>
    </message>
</context>
<context>
    <name>RecordConfig</name>
    <message>
        <location filename="../qml/RecordConfig.qml" line="71"/>
        <source>Video %1.%2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="88"/>
        <source>Stop recording video</source>
        <translation>Zatrzymaj nagrywanie wideo</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="91"/>
        <location filename="../qml/RecordConfig.qml" line="128"/>
        <source>Start recording video</source>
        <translation>Rozpocznij nagrywanie wideo</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="99"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="106"/>
        <source>Insert format description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="193"/>
        <source>Save video as...</source>
        <translation>Zapisz wideo jako ...</translation>
    </message>
</context>
<context>
    <name>Recording</name>
    <message>
        <location filename="../../src/recording.cpp" line="594"/>
        <source>Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="595"/>
        <source>Video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="596"/>
        <source>Subtitle</source>
        <translation>Napisy</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="661"/>
        <location filename="../../src/recording.cpp" line="827"/>
        <source>audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="662"/>
        <location filename="../../src/recording.cpp" line="828"/>
        <source>video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="663"/>
        <location filename="../../src/recording.cpp" line="829"/>
        <source>subtitle</source>
        <translation>napisy</translation>
    </message>
</context>
<context>
    <name>StreamOptions</name>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="28"/>
        <source>Stream #%1 (%2)</source>
        <translation>Strumień #%1 (%2)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="29"/>
        <source>Stream #%1</source>
        <translation>Strumień #%1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="64"/>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="85"/>
        <source>Bitrate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="105"/>
        <source>GOP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="110"/>
        <source>Separation between keyframes</source>
        <translation>Rozdzielenie między klatkami kluczowymi</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="126"/>
        <source>Advanced Codec Options</source>
        <translation>Zaawansowane opcje kodeków</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="150"/>
        <source>Size of the audio (bits) / duration (seconds)</source>
        <translation>Rozmiar audio (bitów) / czas trwania (sekundy)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="171"/>
        <source>Size of the video (bits) / duration (seconds)</source>
        <translation>Rozmiar wideo (bitów) / czas trwania (sekundy)</translation>
    </message>
</context>
<context>
    <name>UpdatesConfig</name>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="68"/>
        <source>Notify about new versions</source>
        <translation>Powiadamiaj o nowych wersjach</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="82"/>
        <source>Check new versions</source>
        <translation>Sprawdź nowe wersje</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="90"/>
        <source>Daily</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="94"/>
        <source>Every two days</source>
        <translation>Co dwa dni</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="98"/>
        <source>Weekly</source>
        <translation>Co tydzień</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="102"/>
        <source>Every two weeks</source>
        <translation>Co dwa tygodnie</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="106"/>
        <source>Monthly</source>
        <translation>Miesięczne</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="110"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="121"/>
        <source>Last updated</source>
        <translation>Ostatnio zaktualizowany</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="142"/>
        <source>Your version of %1 is outdated. Latest version is &lt;b&gt;%2&lt;/b&gt;.</source>
        <translation>Twoja wersja %1 jest nieaktualna. Najnowsza wersja to &lt;b&gt;%2&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="148"/>
        <source>Upgrade Now!</source>
        <translation>Uaktualnij teraz!</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="163"/>
        <source>Thanks for using a &lt;b&gt;development version&lt;/b&gt;!&lt;br /&gt;It will be very helpful if you can report any bug and suggestions you have.</source>
        <translation>Dziękujemy za użycie &lt;b&gt;wersji rozwojowej&lt;/b&gt;!&lt;br /&gt;Będzie bardzo pomocne, jeśli możesz zgłosić dowolny błąd i sugestie.</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="168"/>
        <source>Report a Bug</source>
        <translation>Zgłoś błąd</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="172"/>
        <source>Recording</source>
        <translation>Nagrywanie</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <location filename="../qml/main.qml" line="618"/>
        <source>Play</source>
        <translation>Uruchom</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="652"/>
        <source>Take a photo</source>
        <translation>Zrób zdjęcie</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="252"/>
        <source>Picture %1.%2</source>
        <translation>Obraz %1.%2</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="71"/>
        <source>New version available!</source>
        <translation>Nowa wersja jest dostępna!</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="72"/>
        <source>Download %1 %2 NOW!</source>
        <translation>Pobierz już teraz %1 %2 !</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="107"/>
        <source>Stop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="572"/>
        <source>Go back</source>
        <translation>Wróć</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="626"/>
        <source>Configure sources</source>
        <translation>Skonfiguruj źródła</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="639"/>
        <source>Configure audio</source>
        <translation>Skonfiguruj dźwięk</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="666"/>
        <source>Record video</source>
        <translation>Nagraj wideo</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="680"/>
        <source>Configure Effects</source>
        <translation>Skonfiguruj efekty</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="693"/>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="706"/>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="261"/>
        <source>Save photo as...</source>
        <translation>Zapisz zdjęcie jako...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Aging/share/qml/main.qml" line="40"/>
        <source>Number of scratches</source>
        <translation>Number of scratchesLiczba zadrapań</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Aging/share/qml/main.qml" line="62"/>
        <source>Add dust</source>
        <translation>Dodaj kurz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Blur/share/qml/main.qml" line="40"/>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="77"/>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="93"/>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="43"/>
        <location filename="../../../libAvKys/Plugins/OilPaint/share/qml/main.qml" line="28"/>
        <source>Radius</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="85"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="256"/>
        <source>N° of colors</source>
        <translation>Liczba kolorów</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="107"/>
        <source>Color difference</source>
        <translation>Różnica barw</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="128"/>
        <source>Show edges</source>
        <translation>Pokaż krawędzie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="141"/>
        <source>Threshold low</source>
        <translation>Niski próg</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="166"/>
        <source>Threshold high</source>
        <translation>Wysoki próg</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="190"/>
        <source>Line color</source>
        <translation>Kolor linii</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="205"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="215"/>
        <source>Scan block</source>
        <translation>Skanuj blok</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="195"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="163"/>
        <source>Choose a color</source>
        <translation>Wybierz kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ChangeHSL/share/qml/main.qml" line="36"/>
        <location filename="../../../libAvKys/Plugins/ColorTransform/share/qml/main.qml" line="36"/>
        <location filename="../../../libAvKys/Plugins/MatrixTransform/share/qml/main.qml" line="35"/>
        <source>Transform matrix</source>
        <translation>Przekształcenie macierzy</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="63"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="72"/>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="52"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="63"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="41"/>
        <source>Mode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="73"/>
        <source>Natural</source>
        <translation>Naturalny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="77"/>
        <source>Fixed</source>
        <translation>Naprawiony</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="86"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="76"/>
        <source>Symbols</source>
        <translation>Symbolika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="96"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="85"/>
        <source>Font</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="107"/>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="122"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="526"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="140"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="115"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="104"/>
        <source>Hinting</source>
        <translation>Podpowiedź</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="125"/>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="156"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="114"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="145"/>
        <source>Default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="129"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="118"/>
        <source>No hinting</source>
        <translation>Bez podpowiedzi</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="133"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="122"/>
        <source>Vertical hinting</source>
        <translation>Pionowe podpowiedzi</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="137"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="126"/>
        <source>Full hinting</source>
        <translation>Pełne podpowiedzi</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="146"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="135"/>
        <source>Style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="160"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="149"/>
        <source>Bitmap</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="164"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="153"/>
        <source>Device</source>
        <translation>Urządzenie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="168"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="157"/>
        <source>Outline</source>
        <translation>Zarys</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="172"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="161"/>
        <source>Force outline</source>
        <translation>Zarys sił</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="176"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="165"/>
        <source>Match</source>
        <translation>Mecz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="180"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="169"/>
        <source>Quality</source>
        <translation>Jakość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="184"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="173"/>
        <source>Antialias</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="188"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="177"/>
        <source>No antialias</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="192"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="181"/>
        <source>Compatible with OpenGL</source>
        <translation>Zgodny z OpenGL</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="196"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="185"/>
        <source>Force integer metrics</source>
        <translation>Wymuś liczbę całkowitą</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="200"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="189"/>
        <source>No subpixel antialias</source>
        <translation>Brak antialiasów subpikselowych</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="204"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="193"/>
        <source>No font merging</source>
        <translation>Brak łączenia czcionek</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="213"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="212"/>
        <source>Foreground color</source>
        <translation>Kolor pierwszego planu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="224"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="222"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="138"/>
        <source>Background color</source>
        <translation>Kolor tła</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="235"/>
        <source>Reversed</source>
        <translation>Odwrócone</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="245"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="294"/>
        <source>Please choose a font</source>
        <translation>Wybierz czcionkę</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="217"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="216"/>
        <source>Choose the foreground color</source>
        <translation>Wybierz kolor pierwszego planu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="228"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="226"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="142"/>
        <source>Choose the background color</source>
        <translation>Wybierz kolor tła</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="61"/>
        <location filename="../../../libAvKys/Plugins/Dice/share/qml/main.qml" line="39"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="84"/>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="60"/>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="69"/>
        <source>Color</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="88"/>
        <source>Choose the strips color</source>
        <translation>Wybierz kolor pasków</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="100"/>
        <location filename="../../../libAvKys/Plugins/FalseColor/share/qml/main.qml" line="102"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="83"/>
        <source>Soft</source>
        <translation>Miękkie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="64"/>
        <source>Select the color to filter</source>
        <translation>Wybierz kolor do filtrowania</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="60"/>
        <source>Old color</source>
        <translation>Stary kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="76"/>
        <source>New color</source>
        <translation>Nowy kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="64"/>
        <source>Select the color to replace</source>
        <translation>Wybierz kolor, który chcesz zastąpić</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="80"/>
        <source>Select the new color</source>
        <translation>Wybierz nowy kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="37"/>
        <location filename="../../../libAvKys/Plugins/FalseColor/share/qml/main.qml" line="75"/>
        <source>Color table</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="46"/>
        <source>Base</source>
        <translation>Podstawy</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="50"/>
        <source>Metal</source>
        <translation>Metal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="54"/>
        <source>Heat</source>
        <translation>Ciepły</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="58"/>
        <source>Old Photo</source>
        <translation>Stara Fotografia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="62"/>
        <source>Red &amp; Green</source>
        <translation>Czerwony i Zielony</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="66"/>
        <source>Sepia</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="70"/>
        <source>X-Pro</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="74"/>
        <source>X-Ray</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="78"/>
        <source>Yellow &amp; Blue</source>
        <translation>Żółty i Niebieski</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="82"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="484"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="101"/>
        <source>Custom</source>
        <translation>Niestandardowe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="103"/>
        <source>16x16 bitmap...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="131"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="563"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="202"/>
        <source>Please choose an image file</source>
        <translation>Wybierz plik obrazu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="47"/>
        <source>Convolve matrix</source>
        <translation>Rozmywanie/Wyostrzanie matrix</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="153"/>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Emboss/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/PrimariesColors/share/qml/main.qml" line="28"/>
        <source>Factor</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="167"/>
        <location filename="../../../libAvKys/Plugins/Emboss/share/qml/main.qml" line="43"/>
        <source>Bias</source>
        <translation>Ukos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="42"/>
        <source>Grab mode</source>
        <translation>Tryb przechwytania</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="52"/>
        <source>Random square</source>
        <translation>Losowy kwadrat</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="56"/>
        <source>Vertical increase</source>
        <translation>Pionowy wzrost</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="60"/>
        <source>Horizontal increase</source>
        <translation>Poziomy wzrost</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="64"/>
        <source>Rings increase</source>
        <translation>Pierścienie rosną</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="73"/>
        <location filename="../../../libAvKys/Plugins/Pixelate/share/qml/main.qml" line="41"/>
        <source>Block size</source>
        <translation>Rozmiar bloku</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="86"/>
        <location filename="../../../libAvKys/Plugins/FrameOverlap/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/Nervous/share/qml/main.qml" line="28"/>
        <location filename="../../../libAvKys/Plugins/Quark/share/qml/main.qml" line="28"/>
        <location filename="../../../libAvKys/Plugins/Warhol/share/qml/main.qml" line="28"/>
        <source>N° of frames</source>
        <translation>Liczba ramek</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="78"/>
        <source>Mu</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="92"/>
        <source>Sigma</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DesktopCapture/share/qml/main.qml" line="48"/>
        <source>Frame rate</source>
        <translation>Częstotliwość wyświetlania klatek</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="70"/>
        <source>Amplitude</source>
        <translation>Amplituda</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="43"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="93"/>
        <source>Frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="57"/>
        <source>Grid size</source>
        <translation>Rozmiar siatki</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="49"/>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="74"/>
        <source>Zoom rate</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="97"/>
        <source>Strength</source>
        <translation>Wytrzymałość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="44"/>
        <source>Canny mode</source>
        <translation>Tryb Canny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="57"/>
        <source>Lower Canny threshold</source>
        <translation>Dolny próg Canny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="82"/>
        <source>Higger Canny threshold</source>
        <translation>Próg Higger Canny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="107"/>
        <source>Equalize</source>
        <translation>Wyrównanie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="119"/>
        <source>Invert</source>
        <translation>Odwróć</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="111"/>
        <source>Haar file</source>
        <translation>Jej plik</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="121"/>
        <source>Eye</source>
        <translation>Oko</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="125"/>
        <source>Eye glasses</source>
        <translation>Okulary do oczu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="129"/>
        <source>Frontal face alternative 1</source>
        <translation>Portrety twarzy alternatywnych 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="133"/>
        <source>Frontal face alternative 2</source>
        <translation>Portrety twarzy 2 alternatywne</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="137"/>
        <source>Frontal face alternative 3</source>
        <translation>Portrety twarzy 3 alternatywne</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="141"/>
        <source>Frontal face default</source>
        <translation>Domyślne portrety twarzy</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="145"/>
        <source>Full body</source>
        <translation>Całe ciało</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="149"/>
        <source>Left Eye 1</source>
        <translation>Lewe oko 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="153"/>
        <source>Lower body</source>
        <translation>Dolne części ciała</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="157"/>
        <source>Eye pair big</source>
        <translation>Duża para oczu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="161"/>
        <source>Eye pair small</source>
        <translation>Mała para oczu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="165"/>
        <source>Left ear</source>
        <translation>Lewe ucho</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="169"/>
        <source>Left eye 2</source>
        <translation>Lewe oko 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="173"/>
        <source>Mouth</source>
        <translation>Usta</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="177"/>
        <source>Nose</source>
        <translation>Nos</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="181"/>
        <source>Right ear</source>
        <translation>Prawe ucho</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="185"/>
        <source>Right Eye 1</source>
        <translation>Prawe Oko 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="189"/>
        <source>Upper body 1</source>
        <translation>Górna część ciała 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="193"/>
        <source>Profile face</source>
        <translation>Profil twarzy</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="197"/>
        <source>Right eye 2</source>
        <translation>Prawe oko 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="201"/>
        <source>Smile</source>
        <translation>Uśmiech</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="205"/>
        <source>Upper body</source>
        <translation>Górna część ciała</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="229"/>
        <source>Marker type</source>
        <translation>Typ znacznika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="239"/>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="243"/>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="247"/>
        <source>Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="251"/>
        <source>Pixelate</source>
        <translation>Pikslowanie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="255"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="136"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="94"/>
        <source>Blur</source>
        <translation>Rozmycie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="265"/>
        <source>Marker style</source>
        <translation>Styl znacznika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="275"/>
        <source>Solid</source>
        <translation>Pełny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="279"/>
        <source>Dash</source>
        <translation>Kreska</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="283"/>
        <source>Dot</source>
        <translation>Kropka</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="287"/>
        <source>Dash dot</source>
        <translation>Kreska kropka</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="291"/>
        <source>Dash dot dot</source>
        <translation>Kreska kropka kropka</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="301"/>
        <source>Marker color</source>
        <translation>Kolor znacznika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="313"/>
        <source>Marker width</source>
        <translation>Szerokość znacznika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="327"/>
        <source>Masks</source>
        <translation>Maska</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="336"/>
        <source>Angel</source>
        <translation>Anioł</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="340"/>
        <source>Bear</source>
        <translation>Niedźwiedź</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="344"/>
        <source>Beaver</source>
        <translation>Bóbr</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="348"/>
        <source>Cat</source>
        <translation>Kot</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="352"/>
        <source>Chicken</source>
        <translation>Kurczak</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="356"/>
        <source>Cow</source>
        <translation>Krowa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="360"/>
        <source>Devil</source>
        <translation>Diabeł</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="364"/>
        <source>Dog</source>
        <translation>Pies</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="368"/>
        <source>Dalmatian dog</source>
        <translation>Pies dalmatyńczyk</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="372"/>
        <source>Happy dog</source>
        <translation>Szczęśliwy pies</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="376"/>
        <source>Dragon</source>
        <translation>Smok</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="380"/>
        <source>Elephant 1</source>
        <translation>Słoń 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="384"/>
        <source>Elephant 2</source>
        <translation>Słoń 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="388"/>
        <source>Elk</source>
        <translation>Każdy</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="392"/>
        <source>Frog</source>
        <translation>Żaba</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="396"/>
        <source>Ghost</source>
        <translation>Duch</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="400"/>
        <source>Giraffe</source>
        <translation>Żyrafa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="404"/>
        <source>Gnu</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="408"/>
        <source>Goat</source>
        <translation>Koziorożec</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="412"/>
        <source>Hippo</source>
        <translation>Hipopotam</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="416"/>
        <source>Horse</source>
        <translation>Koń</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="420"/>
        <source>Gray horse</source>
        <translation>Szary koń</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="424"/>
        <source>Koala</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="428"/>
        <source>Monkey</source>
        <translation>Małpa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="432"/>
        <source>Gray mouse</source>
        <translation>Szara myszka</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="436"/>
        <source>White mouse</source>
        <translation>Biała myszka</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="440"/>
        <source>Panda</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="444"/>
        <source>Penguin</source>
        <translation>Pingwin</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="448"/>
        <source>Pumpkin 1</source>
        <translation>Dynia 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="452"/>
        <source>Pumpkin 2</source>
        <translation>Dynia 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="456"/>
        <source>Raccoon</source>
        <translation>Szop</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="460"/>
        <source>Rhino</source>
        <translation>Nosorożec</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="464"/>
        <source>Sheep</source>
        <translation>Owca</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="468"/>
        <source>Skull 1</source>
        <translation>Czaszka 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="472"/>
        <source>Skull 2</source>
        <translation>Czaszka 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="476"/>
        <source>Triceratops</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="480"/>
        <source>Zebra</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="493"/>
        <source>Marker picture</source>
        <translation>Zdjęcie znacznika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="507"/>
        <source>Replace face with this picture.</source>
        <translation>Zastąp twarz tym obrazem.</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="535"/>
        <source>Pixel grid size</source>
        <translation>Rozmiar siatki pikseli</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="549"/>
        <source>Blur radius</source>
        <translation>Promień rozmycia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="305"/>
        <source>Select marker color</source>
        <translation>Wybierz kolor znacznika</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="87"/>
        <source>Hard</source>
        <translation>Twardy</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="97"/>
        <source>Cooling</source>
        <translation>Chłodzenie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="121"/>
        <source>Dissolve</source>
        <translation>Rozpuść</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="151"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="107"/>
        <source>Zoom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="166"/>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="98"/>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="78"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="120"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="90"/>
        <source>Threshold</source>
        <translation>Próg</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="188"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="133"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="103"/>
        <source>Luma threshold</source>
        <translation>Próg Luma</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="210"/>
        <source>Alpha diff</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="234"/>
        <source>Alpha variation</source>
        <translation>Odmiana alfa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FrameOverlap/share/qml/main.qml" line="43"/>
        <source>Stride</source>
        <translation>Krok</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="51"/>
        <source>Pattern</source>
        <translation>Wzór</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="61"/>
        <source>90° Halftone 6x6</source>
        <translation>90° półtony 6x6</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="65"/>
        <source>Cluster 3</source>
        <translation>Grupa 3</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="69"/>
        <source>Cluster 4</source>
        <translation>Grupa 4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="73"/>
        <source>Cluster 8</source>
        <translation>Grupa 8</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="77"/>
        <source>Lines 4x4</source>
        <translation>Linia 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="81"/>
        <source>Magic 2x2</source>
        <translation>Magiczny 2x2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="85"/>
        <source>Magic 4x4</source>
        <translation>Magiczny 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="89"/>
        <source>Ordered 4x4</source>
        <translation>Regulacja 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="93"/>
        <source>Ordered 6x6</source>
        <translation>Ustaw 6x6</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="97"/>
        <source>Ordered 8x8</source>
        <translation>Ustaw 8x8</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="120"/>
        <source>pattern bitmap...</source>
        <translation>wzorzec bitmapy...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="149"/>
        <source>Pattern size</source>
        <translation>Rozmiar wzoru</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="162"/>
        <source>Lightness</source>
        <translation>Lekkość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="175"/>
        <source>Slope</source>
        <translation>Nachylenie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="188"/>
        <source>Intercept</source>
        <translation>Przechwyć</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="63"/>
        <source>Spiral 1</source>
        <translation>Spirala 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="67"/>
        <source>Spiral 2</source>
        <translation>Spirala 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="71"/>
        <source>Parabola</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="75"/>
        <source>Horizontal stripe</source>
        <translation>Poziomy pasek</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="84"/>
        <source>Speed increment</source>
        <translation>Przyrost prędkości</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Implode/share/qml/main.qml" line="28"/>
        <source>Amount</source>
        <translation>Kwota</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="100"/>
        <source>Luma Threshold</source>
        <translation>Próg Luma</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="68"/>
        <source>Choose the automata color</source>
        <translation>Wybierz kolor automatów</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="63"/>
        <source>N° of drops</source>
        <translation>Liczba kropli</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="96"/>
        <source>Select</source>
        <translation>Wybierz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="202"/>
        <source>Cursor color</source>
        <translation>Kolor kursora</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="206"/>
        <source>Choose the cursor color</source>
        <translation>Wybierz kolor kursora</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="232"/>
        <source>Min. drop length</source>
        <translation>Min. długość kropli</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="245"/>
        <source>Max. drop length</source>
        <translation>Max. długość kropli</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="258"/>
        <source>Min. speed</source>
        <translation>Min. prędkość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="271"/>
        <source>Max. speed</source>
        <translation>Max. prędkość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="284"/>
        <source>Show cursor</source>
        <translation>Pokaż kursor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="166"/>
        <source>Output format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="195"/>
        <source>File extensions</source>
        <translation>Rozszerzenia plików</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="201"/>
        <source>This output format has not specific extensions</source>
        <translation>Ten format wyjściowy nie ma określonych rozszerzeń</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="207"/>
        <source>Advanced Format Options</source>
        <translation>Zaawansowane opcje formatu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="119"/>
        <source>Video track</source>
        <translation>Ścieżka wideo</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="132"/>
        <source>Audio track</source>
        <translation>Ścieżka dźwiękowa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="145"/>
        <source>Subtitles track</source>
        <translation>Ścieżka napisów</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Nervous/share/qml/main.qml" line="41"/>
        <source>Simple</source>
        <translation>Proste</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Photocopy/share/qml/main.qml" line="28"/>
        <source>Brightness</source>
        <translation>Jasność</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Photocopy/share/qml/main.qml" line="41"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="73"/>
        <source>Soft normal</source>
        <translation>Miękki normalny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="77"/>
        <source>Hard normal</source>
        <translation>Twardy normalny</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="81"/>
        <source>Soft color</source>
        <translation>Miękki kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="85"/>
        <source>Hard color</source>
        <translation>Mocny kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="146"/>
        <source>Alpha differential</source>
        <translation>Różnica alfa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="159"/>
        <source>Radiation color</source>
        <translation>Kolor promieniowania</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="51"/>
        <source>Motion detect</source>
        <translation>Wykrywanie ruchu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="55"/>
        <source>Rain</source>
        <translation>Deszcz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="77"/>
        <source>Decay</source>
        <translation>Rozkład</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="54"/>
        <source>Show lines</source>
        <translation>Pokaż linie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="67"/>
        <source>Hide lines</source>
        <translation>Ukryj linie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="80"/>
        <source>Hide color</source>
        <translation>Ukryj kolor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="84"/>
        <source>Choose the hide color</source>
        <translation>Wybierz kolor ukrywania</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Scroll/share/qml/main.qml" line="44"/>
        <source>Vertical Sync</source>
        <translation>Synchronizacja pionowa</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Scroll/share/qml/main.qml" line="69"/>
        <source>Noise</source>
        <translation>Szum</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Shagadelic/share/qml/main.qml" line="33"/>
        <source>Mask</source>
        <translation>Maska</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Swirl/share/qml/main.qml" line="38"/>
        <source>Degrees</source>
        <translation>Stopnie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Temperature/share/qml/main.qml" line="38"/>
        <source>Temperature</source>
        <translation>Temperatura</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="215"/>
        <source>Video format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="253"/>
        <source>Resolution</source>
        <translation>Rozdzielczość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="295"/>
        <source>FPS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="344"/>
        <source>Reset</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="83"/>
        <source>Aspect</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="106"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="129"/>
        <source>Softness</source>
        <translation>Miękkość</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="73"/>
        <source>Choose the vignette color</source>
        <translation>Wybierz kolor winiety</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="61"/>
        <source>Devices</source>
        <translation>Urządzenia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="78"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="89"/>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="102"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="113"/>
        <source>Remove All</source>
        <translation>Usuń wszystkie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="134"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="140"/>
        <source>Camera name (optional)</source>
        <translation>Nazwa kamery (opcjonalnie)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="263"/>
        <source>Error creating camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="152"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="195"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="249"/>
        <source>This system is not supported yet</source>
        <translation>Ten system nie jest jeszcze obsługiwany</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Warp/share/qml/main.qml" line="28"/>
        <source>Ripples</source>
        <translation>Marszczenie</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="116"/>
        <source>Phase</source>
        <translation>Faza</translation>
    </message>
</context>
</TS>
